@@ -293,7 +293,7 @@ function listCharacterData($parser, $data) {
 
 			$committime = parseSvnTimestamp($data);
 			$curList->curEntry->committime = $committime;
-			$curList->curEntry->date = strftime('%Y-%m-%d %H:%M:%S', $committime);
+			$curList->curEntry->date = date('Y-m-d H:i:s', $committime);
 			$curList->curEntry->age = datetimeFormatDuration(max(time() - $committime, 0), true, true);
 			break;
 	}
@@ -444,7 +444,7 @@ function logCharacterData($parser, $data) {
 
 			$committime = parseSvnTimestamp($data);
 			$curLog->curEntry->committime = $committime;
-			$curLog->curEntry->date = strftime('%Y-%m-%d %H:%M:%S', $committime);
+			$curLog->curEntry->date = date('Y-m-d H:i:s', $committime);
 			$curLog->curEntry->age = datetimeFormatDuration(max(time() - $committime, 0), true, true);
 			break;
 
@@ -517,7 +517,7 @@ function encodePath($uri) {
 	$parts = explode('/', $uri);
 	$partscount = count($parts);
 	for ($i = 0; $i < $partscount; $i++) {
-		// do not urlencode the 'svn+ssh://' part!
+		// do not rawurlencode the 'svn+ssh://' part!
 		if ($i != 0 || $parts[$i] != 'svn+ssh:') {
 			$parts[$i] = rawurlencode($parts[$i]);
 		}
@@ -684,7 +684,7 @@ class SVNRepository {
 		$shouldTrimOutput = false;
 		$explodeStr = "\n";
 		if ($highlight != 'no' && $config->useGeshi && $geshiLang = $this->highlightLanguageUsingGeshi($path)) {
-			$this->applyGeshi($path, $tempname, $geshiLang, $rev, $peg, $highlight);
+			$this->applyGeshi($path, $tempname, $geshiLang, $rev, $peg, false, $highlight);
 			// Geshi outputs in HTML format, enscript does not
 			$shouldTrimOutput = true;
 			$explodeStr = "<br />";
